==> ah-formbuilder-1.0.14.tgz: package/es/components/app/FieldWrapper.js <==
var _jsxFileName = "/home/mirza/code/formbuilder/src/components/app/FieldWrapper.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from "react";
import { createField as _createField, deleteField as _deleteField } from "../../actions/formActions";
import { enableFieldEdit as _enableFieldEdit, disableFieldEdit as _disableFieldEdit } from "../../actions/toolbarActions";
import { connect } from "react-redux";
import InputWrapper from "./fields-wrappers/Input";
import DeleteIcon from "@material-ui/icons/Delete";
import CloneIcon from "@material-ui/icons/FileCopy";
import EditIcon from "@material-ui/icons/Edit";
import { Tooltip } from "@material-ui/core";
import SelectWrapper from "./fields-wrappers/Select";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Button from "@material-ui/core/Button";
import CheckboxWrapper from "./fields-wrappers/Checkbox";
import RadioWrapper from "./fields-wrappers/Radio";
import DateWrapper from "./fields-wrappers/Date";
import ContentWrapper from "./fields-wrappers/Content";
import FileWrapper from "./fields-wrappers/File";
import SectionWrapper from "./fields-wrappers/Section";
import SignatureWrapper from "./fields-wrappers/Signature";
import ImageWrapper from "./fields-wrappers/Image";
import VideoWrapper from "./fields-wrappers/Video";
import { generateUUID } from "../../utils/helpers";
import { useWindowSize } from "../hooks/useWindowSize";
import _ from "lodash";
import axios from "axios";

function FieldWrapper(props) {
  var _this = this;

  var _React$useState = React.useState(false),
      options = _React$useState[0],
      setOptions = _React$useState[1];

  var _useWindowSize = useWindowSize(),
      width = _useWindowSize.width;

  var enableEdit = function enableEdit(e) {
    props.enableFieldEdit(props.data.uuid);
  };

  var removeField = function removeField(e) {
    if (props.editId === props.data.uuid) {
      props.disableFieldEdit();
    }

    props.deleteField(props.data.uuid);
  };

  var cloneField = function cloneField(e) {
    var _newData$config;

    var uuid = generateUUID();
    var machineName = props.data.type + "-" + Math.round(Date.now() / 1000);

    var newData = _.cloneDeep(props.data);

    newData.uuid = uuid;
    newData.machineName = machineName;

    if (["checkbox", "select", "radio"].includes(newData == null ? void 0 : newData.type) && (newData == null ? void 0 : (_newData$config = newData.config) == null ? void 0 : _newData$config.optionReferenceId)) {
      var _newData$config2;

      // clone predefined
      axios.post(props.predefinedEndpoint + "/clone-option-reference", {
        optionRefId: newData == null ? void 0 : (_newData$config2 = newData.config) == null ? void 0 : _newData$config2.optionReferenceId
      }).then(function (res) {
        props.addCategory(res.data.cloneOptionRef);
        newData.config = _extends({}, newData.config, {
          optionReferenceId: res.data.cloneOptionRef.id
        });
        props.createField(newData);
      });
    } else {
      props.createField(newData);
    }
  };

  var showOptions = function showOptions() {
    setOptions(true);
  };

  var hideOptions = function hideOptions() {
    setOptions(false);
  };

  var renderFields = function renderFields(predefined) {
    switch (props.data.type) {
      case "text":
        return /*#__PURE__*/React.createElement(InputWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 87,
            columnNumber: 11
          }
        });

      case "checkbox":
        return /*#__PURE__*/React.createElement(CheckboxWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 91,
            columnNumber: 11
          }
        });

      case "radio":
        return /*#__PURE__*/React.createElement(RadioWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 99,
            columnNumber: 11
          }
        });

      case "select":
        return /*#__PURE__*/React.createElement(SelectWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 107,
            columnNumber: 11
          }
        });

      case "content":
        return /*#__PURE__*/React.createElement(ContentWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 115,
            columnNumber: 11
          }
        });

      case "date":
        return /*#__PURE__*/React.createElement(DateWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 119,
            columnNumber: 11
          }
        });

      case "file":
        return /*#__PURE__*/React.createElement(FileWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 123,
            columnNumber: 11
          }
        });

      case "image":
        return /*#__PURE__*/React.createElement(ImageWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 127,
            columnNumber: 11
          }
        });

      case "list":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 130,
            columnNumber: 16
          }
        }, "list");

      case "quiz":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 132,
            columnNumber: 16
          }
        }, "quiz");

      case "signature":
        return /*#__PURE__*/React.createElement(SignatureWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 135,
            columnNumber: 11
          }
        });

      case "survey":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 138,
            columnNumber: 16
          }
        }, "survey");

      case "video":
        return /*#__PURE__*/React.createElement(VideoWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 141,
            columnNumber: 11
          }
        });

      case "section":
        return /*#__PURE__*/React.createElement(SectionWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 145,
            columnNumber: 11
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 148,
            columnNumber: 16
          }
        }, " Default ");
    }
  };

  var className = "wrapper ahfb-shadow-1 ahfb-bg-white ahfb-ml-3 ahfb-mr-3 ahfb-p-3 ahfb-relative";

  if (props.first) {
    className = className + " first-field";
  }

  if (props.last) {
    className = className + " last-field";
  }

  var predefined = {};
  props.predefined.map(function (item) {
    predefined[item.id] = item;
  });
  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 164,
      columnNumber: 5
    }
  }, props.data.name || props.data.type === "content" || props.data.type === "image" || props.data.type === "video" ? /*#__PURE__*/React.createElement("div", {
    className: className,
    onMouseOver: showOptions,
    onMouseLeave: hideOptions,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 169,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "innerWrapper",
    style: {
      marginTop: width < 450 ? "30px" : ""
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 174,
      columnNumber: 11
    }
  }, options ? /*#__PURE__*/React.createElement(ButtonGroup, {
    className: "options-menu ahfb-absolute ahfb-" + (props.theme.direction ? props.theme.direction : "ltr") + "-1 ahfb-top-1 ahfb-float-right ahfb-zIndex",
    color: "primary",
    size: "small",
    "aria-label": "outlined primary button group",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 179,
      columnNumber: 15
    }
  }, /*#__PURE__*/React.createElement(Button, {
    className: "delete-icon",
    onClick: removeField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 187,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(DeleteIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 188,
      columnNumber: 19
    }
  })), /*#__PURE__*/React.createElement(Button, {
    className: "edit-icon",
    onClick: enableEdit,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 190,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(EditIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 191,
      columnNumber: 19
    }
  })), props.data.type !== "section" ? /*#__PURE__*/React.createElement(Button, {
    className: "clone-icon",
    onClick: cloneField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 194,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(Tooltip, {
    title: "Clone field",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 195,
      columnNumber: 21
    }
  }, /*#__PURE__*/React.createElement(CloneIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 196,
      columnNumber: 23
    }
  }))) : "") : "", renderFields(predefined))) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    editId: state.toolbar.editId,
    predefined: state.form.predefined,
    predefinedEndpoint: state.form.predefinedEndpoint,
    theme: state.form.theme,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    createField: function createField(id) {
      return dispatch(_createField(id));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    },
    enableFieldEdit: function enableFieldEdit(id) {
      return dispatch(_enableFieldEdit(id));
    },
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    addCategory: function (_addCategory) {
      function addCategory(_x) {
        return _addCategory.apply(this, arguments);
      }

      addCategory.toString = function () {
        return _addCategory.toString();
      };

      return addCategory;
    }(function (id) {
      return dispatch(addCategory(id));
    })
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(FieldWrapper);

==> ah-formbuilder-1.0.30.tgz: package/es/components/app/FieldWrapper.js <==
var _jsxFileName = "/home/mirza/code/formbuilder/src/components/app/FieldWrapper.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from "react";
import { createField as _createField, deleteField as _deleteField } from "../../actions/formActions";
import { enableFieldEdit as _enableFieldEdit, disableFieldEdit as _disableFieldEdit } from "../../actions/toolbarActions";
import { connect } from "react-redux";
import InputWrapper from "./fields-wrappers/Input";
import DeleteIcon from "@material-ui/icons/Delete";
import CloneIcon from "@material-ui/icons/FileCopy";
import EditIcon from "@material-ui/icons/Edit";
import { Tooltip } from "@material-ui/core";
import SelectWrapper from "./fields-wrappers/Select";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Button from "@material-ui/core/Button";
import CheckboxWrapper from "./fields-wrappers/Checkbox";
import RadioWrapper from "./fields-wrappers/Radio";
import DateWrapper from "./fields-wrappers/Date";
import ContentWrapper from "./fields-wrappers/Content";
import FileWrapper from "./fields-wrappers/File";
import SectionWrapper from "./fields-wrappers/Section";
import SignatureWrapper from "./fields-wrappers/Signature";
import ImageWrapper from "./fields-wrappers/Image";
import VideoWrapper from "./fields-wrappers/Video";
import { generateUUID, getUniqueNumber } from '../../utils/helpers';
import { useWindowSize } from "../hooks/useWindowSize";
import _ from "lodash";
import axios from "axios";
import { addCategory as _addCategory } from '../../actions/predefinedActions';

function FieldWrapper(props) {
  var _this = this;

  var _React$useState = React.useState(false),
      options = _React$useState[0],
      setOptions = _React$useState[1];

  var _useWindowSize = useWindowSize(),
      width = _useWindowSize.width;

  var enableEdit = function enableEdit(e) {
    props.enableFieldEdit(props.data.uuid);
  };

  var removeField = function removeField(e) {
    if (props.editId === props.data.uuid) {
      props.disableFieldEdit();
    }

    props.deleteField(props.data.uuid);
  };

  var cloneField = function cloneField(e) {
    var _newData$config;

    var uuid = generateUUID();
    var machineName = props.data.type + "-" + getUniqueNumber();

    var newData = _.cloneDeep(props.data);

    newData.uuid = uuid;
    newData.machineName = machineName;

    if (["checkbox", "select", "radio"].includes(newData == null ? void 0 : newData.type) && (newData == null ? void 0 : (_newData$config = newData.config) == null ? void 0 : _newData$config.optionReferenceId)) {
      var preDef = props.predefined.find(function (item) {
        var _newData$config2;

        return item.id === (newData == null ? void 0 : (_newData$config2 = newData.config) == null ? void 0 : _newData$config2.optionReferenceId);
      });
      var clonePredef = {
        id: getUniqueNumber(),
        name: preDef.name + '_clone_' + getUniqueNumber(),
        slug: preDef.slug + '_clone_' + getUniqueNumber(),
        is_public: false,
        is_secure: false,
        isNew: true,
        options: preDef.options.map(function (item) {
          return _extends({}, item, {
            id: getUniqueNumber()
          });
        })
      };
      props.addCategory(clonePredef);
      newData.config = _extends({}, newData.config, {
        optionReferenceId: clonePredef.id
      });
      props.createField(newData); // clone predefined
      // axios
      //   .post(`${props.predefinedEndpoint}/clone-option-reference`, {
      //     optionRefId: newData?.config?.optionReferenceId,
      //   })
      //   .then((res) => {
      //     props.addCategory(res.data.cloneOptionRef);
      //     newData.config = {
      //       ...newData.config,
      //       optionReferenceId: res.data.cloneOptionRef.id,
      //     };
      //     props.createField(newData);
      //   });
    } else {
      props.createField(newData);
    }
  };

  var showOptions = function showOptions() {
    setOptions(true);
  };

  var hideOptions = function hideOptions() {
    setOptions(false);
  };

  var renderFields = function renderFields(predefined) {
    switch (props.data.type) {
      case "text":
        return /*#__PURE__*/React.createElement(InputWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 104,
            columnNumber: 11
          }
        });

      case "checkbox":
        return /*#__PURE__*/React.createElement(CheckboxWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 108,
            columnNumber: 11
          }
        });

      case "radio":
        return /*#__PURE__*/React.createElement(RadioWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 116,
            columnNumber: 11
          }
        });

      case "select":
        return /*#__PURE__*/React.createElement(SelectWrapper, {
          data: props.data,
          predefined: predefined,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 124,
            columnNumber: 11
          }
        });

      case "content":
        return /*#__PURE__*/React.createElement(ContentWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 132,
            columnNumber: 11
          }
        });

      case "date":
        return /*#__PURE__*/React.createElement(DateWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 136,
            columnNumber: 11
          }
        });

      case "file":
        return /*#__PURE__*/React.createElement(FileWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 140,
            columnNumber: 11
          }
        });

      case "image":
        return /*#__PURE__*/React.createElement(ImageWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 144,
            columnNumber: 11
          }
        });

      case "list":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 147,
            columnNumber: 16
          }
        }, "list");

      case "quiz":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 149,
            columnNumber: 16
          }
        }, "quiz");

      case "signature":
        return /*#__PURE__*/React.createElement(SignatureWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 152,
            columnNumber: 11
          }
        });

      case "survey":
        return /*#__PURE__*/React.createElement("h1", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 155,
            columnNumber: 16
          }
        }, "survey");

      case "video":
        return /*#__PURE__*/React.createElement(VideoWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 158,
            columnNumber: 11
          }
        });

      case "section":
        return /*#__PURE__*/React.createElement(SectionWrapper, {
          data: props.data,
          currentLang: props.currentLang,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 162,
            columnNumber: 11
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 165,
            columnNumber: 16
          }
        }, " Default ");
    }
  };

  var className = "wrapper ahfb-shadow-1 ahfb-bg-white ahfb-ml-3 ahfb-mr-3 ahfb-p-3 ahfb-relative";

  if (props.first) {
    className = className + " first-field";
  }

  if (props.last) {
    className = className + " last-field";
  }

  var predefined = {};
  props.predefined.map(function (item) {
    predefined[item.id] = item;
  });
  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 181,
      columnNumber: 5
    }
  }, props.data.name || props.data.type === "content" || props.data.type === "image" || props.data.type === "video" ? /*#__PURE__*/React.createElement("div", {
    className: className,
    onMouseOver: showOptions,
    onMouseLeave: hideOptions,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 186,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "innerWrapper",
    style: {
      marginTop: width < 450 ? "30px" : ""
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 191,
      columnNumber: 11
    }
  }, options ? /*#__PURE__*/React.createElement(ButtonGroup, {
    className: "options-menu ahfb-absolute ahfb-" + (props.theme.direction ? props.theme.direction : "ltr") + "-1 ahfb-top-1 ahfb-float-right ahfb-zIndex",
    color: "primary",
    size: "small",
    "aria-label": "outlined primary button group",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 196,
      columnNumber: 15
    }
  }, /*#__PURE__*/React.createElement(Button, {
    className: "delete-icon",
    onClick: removeField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 204,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(DeleteIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 205,
      columnNumber: 19
    }
  })), /*#__PURE__*/React.createElement(Button, {
    className: "edit-icon",
    onClick: enableEdit,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 207,
      columnNumber: 17
    }
  }, /*#__PURE__*/React.createElement(EditIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 208,
      columnNumber: 19
    }
  })), props.data.type !== "section" ? /*#__PURE__*/React.createElement(Button, {
    className: "clone-icon",
    onClick: cloneField,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 211,
      columnNumber: 19
    }
  }, /*#__PURE__*/React.createElement(Tooltip, {
    title: "Clone field",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 212,
      columnNumber: 21
    }
  }, /*#__PURE__*/React.createElement(CloneIcon, {
    fontSize: "small",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 213,
      columnNumber: 23
    }
  }))) : "") : "", renderFields(predefined))) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    editId: state.toolbar.editId,
    predefined: state.form.predefined,
    predefinedEndpoint: state.form.predefinedEndpoint,
    theme: state.form.theme,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    createField: function createField(id) {
      return dispatch(_createField(id));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    },
    enableFieldEdit: function enableFieldEdit(id) {
      return dispatch(_enableFieldEdit(id));
    },
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    addCategory: function addCategory(id) {
      return dispatch(_addCategory(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(FieldWrapper);
